@@ -28,7 +28,6 @@ GetOptions(\%opt,
     'optimize',
     'optimize-days=i',
     'index-basename=s',
-    'date-separator=s',
     'timezone=s',
     'skip-alias=s@',
     # Basic options
@@ -240,7 +239,7 @@ es-daily-index-maintenance.pl - Run to prune old indexes and optimize existing
 
 =head1 VERSION
 
-version 8.6
+version 8.7
 
 =head1 SYNOPSIS
 
@@ -282,7 +281,6 @@ From App::ElasticSearch::Utilities:
     --index         Index to run commands against
     --base          For daily indexes, reference only those starting with "logstash"
                      (same as --pattern logstash-* or logstash-DATE)
-    --datesep       Date separator, default '.' also (--date-separator)
     --pattern       Use a pattern to operate on the indexes
     --days          If using a pattern or base, how many days back to go, default: 1
 
